==> haskell-hspec-megaparsec-2.2.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-CeGsZvTLvIcDtyNkD7pYH2
key:                  hspec-megaparsec-2.2.1-CeGsZvTLvIcDtyNkD7pYH2
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  da74857e0f5a736aa88d381cd6217089
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-CeGsZvTLvIcDtyNkD7pYH2
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    megaparsec-9.5.0-7z3AThgMzs3rnIZVIvVtE

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.2.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-5dN3UK2cNjsFLa0jQQI2YL
key:                  hspec-megaparsec-2.2.1-5dN3UK2cNjsFLa0jQQI2YL
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  37b36ac729954e84956a638274b1eb70
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-5dN3UK2cNjsFLa0jQQI2YL
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    megaparsec-9.6.1-xFWwysPvLWIMfIZXM34tr

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
